Django-photologue
=================
.. image:: https://img.shields.io/pypi/v/django-photologue.svg
    :target: https://pypi.python.org/pypi/django-photologue/
    :alt: Latest PyPI version

.. image:: https://github.com/richardbarran/django-photologue/workflows/CI/badge.svg?branch=master
     :target: https://github.com/richardbarran/django-photologue/actions?workflow=CI
     :alt: CI Status

.. image:: https://codecov.io/github/richardbarran/django-photologue/coverage.svg?branch=master
    :target: https://codecov.io/github/richardbarran/django-photologue?branch=master


A powerful image management and gallery application for the Django web framework. Upload photos, group them into
galleries, apply effects such as watermarks.

Take a closer look
------------------
- We have a `demo website <http://www.django-photologue.net/>`_.
- We also have some `examples of sites using Photologue
  <https://github.com/richardbarran/django-photologue/wiki/Examples-and-forks>`_ on the wiki.

Documentation
-------------
Please head over to our `online documentation at ReadTheDocs <https://django-photologue.readthedocs.io/en/stable/>`_
for instructions on installing and configuring this application.

Amazon S3
---------

S3 also works with the standard BOTO package.

Support
-------
If you have any questions or need help with any aspect of Photologue then please `join our mailing list
<http://groups.google.com/group/django-photologue>`_.
